#Emperically determines the plot size and layout for relating plots to in-situ data
#John Hogland 12/3/2018

#setup directories
baseDir <- "C:\\temp"
LandsatImgDir <- paste(baseDir, "Landsat", sep = "\\")
NaipImgDir <- paste(baseDir,"NAIP",sep = "\\")
setwd(baseDir)
source("C:\\temp\\jhLib.R")

#get genearal numbers for max continuity
#df.gNumbers<-data.frame(img=character(),band=integer(),mean=double(),sill=double(),range=double())
#for(p in imgPaths)
#{
#  print(tDf<-getSampledMaxSillRange(p))
#  df.gNumbers<-rbind(df.gNumbers,tDf)
#}

#create rasters
#for (i in seq(0.5,30,5))
#{
#  rs<-getSpCorrImages(1000,1000,i,mn=2080,vr=245416,maxDist=60,ng=?)
#  writeRaster(rs,paste("Range",i,".tif",sep=""),format="GTiff",overwrite=TRUE)
#}

LandsatImgPaths<-getImgPath(LandsatImgDir)
NaipImgPaths <- getImgPath(NaipImgDir)

#setup simulations
sampSize <- 200
blockWidth <- c(1, seq(3, 15, 3), seq(20, 55, 5), seq(60, 100, 10))

#Landsat 8 and GPS errors in pixels
shiftImg<-48/30#*rmseImage #95% of the data (pixels) Landsat 37m 90% CI = 47.48m @ 95%
shiftGps<-7/30#*rmseGps #95% of the data (pixels) 

#using all the data within a plot boundary (blockSize) to determine size of the plot for Landsat
dfRegL <- SimSampling(LandsatImgPaths, sampSize, blockWidth, shiftGps, shiftImg)
for (i in 1:9) {
    dfRegL <- rbind(dfRegL,SimSampling(LandsatImgPaths, sampSize, blockWidth, shiftGps, shiftImg))
}
write.csv(dfRegL, "LandsatBlockSizeReg10.csv")

#NAIP and GPS errors in pixels
shiftImg <- 6 #*rmseImage #95% of the data (pixels) NAIP
shiftGps <- 7 #*rmseGps #95% of the data (pixels)

#using all the data within a plot boundary (blockSize) to determine size of the plot for NAIP
dfRegN <- SimSampling(NaipImgPaths, sampSize, blockWidth, shiftGps, shiftImg)
for (i in 1:9) {
    dfRegN <- rbind(dfRegN, SimSampling(NaipImgPaths, sampSize, blockWidth, shiftGps, shiftImg))
}
write.csv(dfRegN,"NaipBlockSizeReg10.csv")

#Using BlockSizes between 20 and 50 cells with varying layouts and proportions of area sampled (0.5-0.95 by 0.5) NAIP
blockWidth <- seq(20, 50, 5)
dfRegLayN <- SimSampling(NaipImgPaths, sampSize, blockWidth, shiftGps, shiftImg, seq(0.05, 1, 0.05))
write.csv(dfRegLayN, "NaipBlockSizeRegLayout.csv")

#Landsat
#Changing shift back to Landsat
blockWidth <- seq(5, 35, 5)
shiftImg <- 48/30 #*rmseImage #95% of the data (pixels) Landsat
shiftGps <- 7/30 #*rmseGps #95% of the data (pixels)
dfRegLayL <- SimSampling(LandsatImgPaths, sampSize, blockWidth, shiftGps, shiftImg, seq(0.05, 1, 0.05))
write.csv(dfRegLayL, "LandsatBlockSizeRegLayout.csv")

#diff between total R2
lsLayout <- read.csv("LandsatBlockSizeRegLayout.csv")
lsLayout$DR2 <- compareValues(lsLayout, "R2", 40)
lsLayout$DRMSE <- compareValues(lsLayout, "RMSE", 40)
write.csv(lsLayout, "LandsatBlockSizeRegLayout.csv")

naipLayout <- read.csv("NaipBlockSizeRegLayout.csv")
naipLayout$DR2 <- compareValues(naipLayout, "R2", 40)
naipLayout$DRMSE <- compareValues(naipLayout, "RMSE",40)
write.csv(naipLayout, "NaipBlockSizeRegLayout.csv")

