#Regress Results from simulations
#Use overlape regions, blocksize, and Moran's I to estiamte R2
#John Hogland 12/3/2018
library(betareg)
library(ggplot2)
library(grid)
library(gridExtra)
baseDir <- "C:\\temp"
setwd(baseDir)
source("C:\\temp\\jhLib.R")

#linear models
#Landsat
lsDf <- read.csv("LandsatBlockSizeReg10.csv")
#aggregate 10 iterations
lsDf <- aggregate(lsDf, by = list(lsDf$NAME, lsDf$BAND, lsDf$BLOCKSIZE), FUN = mean, na.rm = TRUE)
#subset data to random landscape and perform linear regression
lsDf.rnd <- subset(lsDf, Group.1 == "LS_Range0.5")
frm <- formula("R2 ~ 0+I(OVERLAP^2)")
md <- lm(frm, data = lsDf.rnd)
summary(md)

#Perform BetaRegression
frm1 <- formula("R2~BLOCKSIZE")
gyBeta1 <- betareg(frm1, data = lsDf, link = "logit")
AIC(gyBeta1)
frm2 <- formula("R2~BLOCKSIZE+MORI")
gyBeta2 <- betareg(frm2, data = lsDf, link = "logit")
AIC(gyBeta2)
frm3 <- formula("R2~BLOCKSIZE*MORI")
gyBeta3 <- betareg(frm3, data = lsDf, link = "logit")
AIC(gyBeta3)
frm4 <- formula("R2~log(BLOCKSIZE)")
gyBeta4 <- betareg(frm4, data = lsDf, link = "logit")
AIC(gyBeta4)
frm5 <- formula("R2~log(BLOCKSIZE)+exp(MORI)")
gyBeta5 <- betareg(frm5, data = lsDf, link = "logit")
AIC(gyBeta5)
frm6 <- formula("R2~log(BLOCKSIZE)*exp(MORI)")
gyBeta6 <- betareg(frm6, data = lsDf, link = "logit")
AIC(gyBeta6)
frm <- formula("R2~log(BLOCKSIZE)*exp(MORI)")
gyBetals <- betareg(frm, data = lsDf, link = "logit")
summary(predict(gyBetals))
sqrt(mean((predict(gyBetals) - lsDf$R2) ^ 2))

#NAIP
naipDf <- read.csv("NaipBlockSizeReg10.csv")
#aggregate 10 iterations
naipDf <- aggregate(naipDf, by = list(naipDf$NAME, naipDf$BAND, naipDf$BLOCKSIZE), FUN = mean, na.rm = TRUE)
#subset data to random landscape and perform linear regression
naipDf.rnd <- subset(naipDf, Group.1 == "NAIP_Range0.5")
frm <- formula("R2 ~ 0+I(OVERLAP^2)")
summary(tls <- lm(frm, data=naipDf.rnd))

#Perform beta regression
frm1 <- formula("R2~BLOCKSIZE")
gyBeta1 <- betareg(frm1, data = naipDf, link = "logit")
AIC(gyBeta1)
frm2 <- formula("R2~BLOCKSIZE+MORI")
gyBeta2 <- betareg(frm2, data = naipDf, link = "logit")
AIC(gyBeta2)
frm3 <- formula("R2~BLOCKSIZE*MORI")
gyBeta3 <- betareg(frm3, data = naipDf, link = "logit")
AIC(gyBeta3)
frm4 <- formula("R2~log(BLOCKSIZE)")
gyBeta4 <- betareg(frm4, data = naipDf, link = "logit")
AIC(gyBeta4)
frm5 <- formula("R2~log(BLOCKSIZE)+exp(MORI)")
gyBeta5 <- betareg(frm5, data = naipDf, link = "logit")
AIC(gyBeta5)
frm6 <- formula("R2~log(BLOCKSIZE)*exp(MORI)")
gyBeta6 <- betareg(frm6, data = naipDf, link = "logit")
AIC(gyBeta6)
frm <- formula("R2~log(BLOCKSIZE)*exp(MORI)")
gyBeta <- betareg(frm, data = naipDf, link = "logit")
summary(gyBeta)
sqrt(mean((predict(gyBeta) - naipDf$R2) ^ 2))


#plots


#Figure 6
tdf <- lsDf[grep("Florida", lsDf$Group.1, invert = TRUE),]
tdf$Range <- gsub("LS_Range", "", tdf$Group.1)
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("0.5", "5.5", "10.5","15.5","20.5","25.5","30.5","35.5","40.5"))
cbPalette <- c("#000000","#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
plot.new()
png("fig6.png", width = 1200, height = 800, res = 100)
p1 <- ggplot(tdf, aes(BLOCKSIZE, R2, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + xlim(0, 100) + ylim(0, 1) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))
p2 <- ggplot(tdf, aes(BLOCKSIZE, RMSE, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p3 <- ggplot(tdf, aes(BLOCKSIZE, INTERCEPT, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p4 <- ggplot(tdf, aes(BLOCKSIZE, SLOPE, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
grid.arrange(p1, p2, p3, p4, nrow = 2, ncol = 2)
dev.off()

#Figure A1
tdf <- lsDf[grep("Florida", lsDf$Group.1, invert = FALSE),]
tdf$Band <- as.character(tdf$BAND)
tdf <- tdf[order(as.numeric(tdf$Band)),]
tdf$Band <- factor(tdf$Band, levels = c("1", "2", "3", "4", "5", "6", "7"))
cbPalette <- c("#000000", "#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2")

ggplot(tdf, aes(BLOCKSIZE, R2, color = Band)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(axis.ticks.x = element_blank(), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17),legend.text = element_text(size=15),legend.title=element_text(size=15)) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))

plot.new()
png("figA1.png", width = 1200, height = 800, res = 100)
p1 <- ggplot(tdf, aes(BLOCKSIZE, R2, color = Band)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + xlim(0, 100) + ylim(0.75, 1) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))
p2 <- ggplot(tdf, aes(BLOCKSIZE, RMSE, color = Band)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p3 <- ggplot(tdf, aes(BLOCKSIZE, INTERCEPT, color = Band)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p4 <- ggplot(tdf, aes(BLOCKSIZE, SLOPE, color = Band)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette) + xlim(0, 100) + ylim(0.95, 1.005)
grid.arrange(p1, p2, p3, p4, nrow = 2, ncol = 2)
dev.off()

#Figure 7
tdf <- naipDf[grep("NAIP", naipDf$Group.1, invert = FALSE),]
tdf$Range <- gsub("NAIP_Range", "", tdf$Group.1)
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("0.5", "5.5", "10.5", "15.5", "20.5", "25.5", "30.5", "35.5", "40.5","45.5"))
cbPalette <- c("#000000", "#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "green")
plot.new()
png("fig7.png", width = 1200, height = 800, res = 100)
p1 <- ggplot(tdf, aes(BLOCKSIZE, R2, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + xlim(0, 100) + ylim(0, 1) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))
p2 <- ggplot(tdf, aes(BLOCKSIZE, RMSE, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p3 <- ggplot(tdf, aes(BLOCKSIZE, INTERCEPT, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
p4 <- ggplot(tdf, aes(BLOCKSIZE, SLOPE, color = Range)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
grid.arrange(p1, p2, p3, p4, nrow = 2, ncol = 2)
dev.off()

#Figure A2
tdf <- naipDf[grep("NAIP", naipDf$Group.1, invert = TRUE),]
tdf$Band <- as.character(tdf$BAND)
tdf <- tdf[order(as.numeric(tdf$Band)),]
tdf$Band <- factor(tdf$Band, levels = c("1", "2", "3", "4"))
cbPalette <- c("#000000", "#999999", "#E69F00", "#56B4E9", "#009E73")

ggplot(tdf, aes(BLOCKSIZE, R2, color = Group.1)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(axis.ticks.x = element_blank(), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17), legend.text = element_text(size = 15), legend.title = element_text(size = 15)) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))


for (n in unique(tdf$Band)) {
    plot.new()
    tdfs<-tdf[tdf$Band == n,]
    png(paste("figA2_",as.character(as.numeric(n)+1),".png",sep=""), width = 1200, height = 800, res = 100)
    p1 <- ggplot(tdfs, aes(BLOCKSIZE, R2, color = Group.1)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + xlim(0, 100) + ylim(0, 1) + scale_colour_manual(values = cbPalette) + ylab(bquote(~R ^ 2))
    p2 <- ggplot(tdfs, aes(BLOCKSIZE, RMSE, color = Group.1)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
    p3 <- ggplot(tdfs, aes(BLOCKSIZE, INTERCEPT, color = Group.1)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
    p4 <- ggplot(tdfs, aes(BLOCKSIZE, SLOPE, color = Group.1)) + geom_line(size = 1) + geom_point(size = 2) + theme_light() + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 15), axis.title.y = element_text(size = 17)) + scale_colour_manual(values = cbPalette)
    grid.arrange(p1, p2, p3, p4, nrow = 2, ncol = 2)
    dev.off()
    }

#Figure 8
plot.new()
png("fig8.png", width = 600, height = 300, res = 100)
p1 <- ggplot(lsDf.rnd, aes(OVERLAP ^ 2, R2, col = BLOCKSIZE)) + geom_point(size = 2) + geom_abline(intercept = 0, slope = 1, color = "gray") + theme_light() + xlim(0, 1) + ylim(0, 1) + xlab(bquote(~R ^ 2)) + ylab(bquote(~OVERLAP ^ 2)) + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
p2 <- ggplot(naipDf.rnd, aes(OVERLAP ^ 2, R2, col = BLOCKSIZE)) + geom_point(size = 2) + geom_abline(intercept = 0, slope = 1, color = "gray") + theme_light() + xlim(0, 1) + ylim(0, 1) + xlab(bquote(~R ^ 2)) + ylab(bquote(~OVERLAP ^ 2)) + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
grid.arrange(p1,p2,nrow=1,ncol=2)
dev.off()

#Figure 10
plot.new()
png("fig10.png", width = 600, height = 300, res = 100)
lsDf$BPRED <- predict(gyBetals)
p1 <- ggplot(lsDf, aes(R2, BPRED, col = BLOCKSIZE)) + geom_point(size = 2) + geom_abline(intercept = 0, slope = 1, color = "gray") + theme_light() + xlim(0, 1) + ylim(0, 1) + xlab(bquote(~R ^ 2)) + ylab(bquote(~OVERLAP ^ 2)) + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
naipDf$BPRED<-predict(gyBeta)
p2 <- ggplot(naipDf, aes(R2, BPRED, col = BLOCKSIZE)) + geom_point(size = 2) + geom_abline(intercept = 0, slope = 1, color = "gray") + theme_light() + xlim(0, 1) + ylim(0, 1) + xlab(bquote(~R ^ 2)) + ylab(bquote(~OVERLAP ^ 2)) + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
grid.arrange(p1, p2, nrow = 1, ncol = 2)
dev.off()

#Fig 9
lsLayout <- read.csv("LandsatBlockSizeRegLayout.csv")
cbPalette <- c("#000000", "#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "green")
tdf <- lsLayout[grep("Florida", lsLayout$NAME, invert = TRUE),]
tdf$Range <- gsub("LS_Range", "", tdf$NAME)
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("0.5", "5.5", "10.5", "15.5", "20.5", "25.5", "30.5", "35.5", "40.5"))

tdft <- tdf[tdf$BLOCKSIZE <= 15 & tdf$TYPE == 2 & tdf$LAYOUT == 2,]
plot.new()
png("fig9a.png", width = 1200, height = 400, res = 100)
ggplot(tdft, aes(TPROP, DR2, color = Range)) + geom_line(size = 1) + geom_jitter(size = 1.5, width = 0.01, height = 0.01, shape = 21, fill = NA) + theme_light() + scale_colour_manual(values = cbPalette) + facet_wrap(~BLOCKSIZE, ncol = 3) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
dev.off()

naipLayout <- read.csv("NaipBlockSizeRegLayout.csv")
tdf <- naipLayout[grep("NAIP", naipLayout$NAME, invert = FALSE),]
tdf$Range <- gsub("NAIP_Range", "", tdf$NAME)
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("0.5", "5.5", "10.5", "15.5", "20.5", "25.5", "30.5", "35.5", "40.5", "45.5"))
tdft <- tdf[(tdf$BLOCKSIZE == 20 | tdf$BLOCKSIZE == 30 | tdf$BLOCKSIZE == 40) & tdf$TYPE == 2 & tdf$LAYOUT==2,]
plot.new()
png("fig9b.png", width = 1200, height = 400, res = 100)
ggplot(tdft, aes(TPROP, DR2, color = Range)) + geom_line(size = 1) + geom_jitter(size = 1.5, width = 0.01, height = 0.01, shape = 21, fill = NA) + theme_light() + scale_colour_manual(values = cbPalette) + facet_wrap(~BLOCKSIZE, ncol = 3) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
dev.off()

#Fig A3
lsLayout <- read.csv("LandsatBlockSizeRegLayout.csv")
cbPalette <- c("#000000", "#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "green")
tdf <- lsLayout[grep("Florida", lsLayout$NAME, invert = FALSE),]
tdf$Range <-  tdf$BAND
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("1", "2", "3", "4", "5", "6", "7"))

tdft <- tdf[tdf$BLOCKSIZE <= 15 & tdf$TYPE == 2 & tdf$LAYOUT == 2,]
plot.new()
png("figA3.png", width = 1200, height = 400, res = 100)
ggplot(tdft, aes(TPROP, DR2, color = Range)) + geom_line(size = 1) + geom_jitter(size = 1.5, width = 0.01, height = 0.001, shape = 21, fill = NA) + theme_light() + scale_colour_manual(values = cbPalette) + facet_wrap(~BLOCKSIZE, ncol = 3) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())
dev.off()

#fig A4
naipLayout <- read.csv("NaipBlockSizeRegLayout.csv")
tdf <- naipLayout[grep("NAIP", naipLayout$NAME, invert = TRUE),]
tdf$Range <- tdf$BAND
tdf <- tdf[order(as.numeric(tdf$Range)),]
tdf$Range <- factor(tdf$Range, levels = c("1", "2", "3", "4"))
tdft <- tdf[(tdf$BLOCKSIZE == 20 | tdf$BLOCKSIZE == 30 | tdf$BLOCKSIZE == 40) & tdf$TYPE == 2 & tdf$LAYOUT == 2,]
plot.new()
png("figA4.png", width = 1200, height = 1200, res = 100)
ggplot(tdft, aes(TPROP, DR2, color = NAME)) + geom_line(size = 1) + geom_jitter(size = 1.5, width = 0.01, height = 0.01, shape = 21, fill = NA) + theme_light() + scale_colour_manual(values = cbPalette) + facet_wrap(~Range + BLOCKSIZE, ncol = 3) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank(), strip.background = element_blank(), strip.text = element_blank())
dev.off()

#fig A5
frm <- formula("R2~log(BLOCKSIZE)*exp(MORI)")
gyBetaNaip <- betareg(frm, data = naipDf, link = "logit")
gyBetaLs <- betareg(frm, data = lsDf, link = "logit")
lsDf$Res <- residuals(gyBetaLs)
lsDf$lPRED <- log(gyBetaLs$fitted.values / (1 - gyBetaLs$fitted.values))
plot.new()
png("fig5A.png", width = 600, height = 300, res = 100)
p1 <- ggplot(lsDf, aes(lPRED, Res, col = BLOCKSIZE)) + geom_point(size = 2) + theme_light() + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank()) + ylim(-4.1, 4) 
naipDf$Res <- residuals(gyBetaNaip)
naipDf$lPRED <- log(gyBetaNaip$fitted.values / (1 - gyBetaNaip$fitted.values))
p2 <- ggplot(naipDf, aes(lPRED,Res, col = BLOCKSIZE)) + geom_point(size = 2) + theme_light() + scale_color_gradientn(colours = rainbow(5)) + theme(legend.position = "none", axis.title.x = element_blank(), axis.text = element_text(size = 12), axis.title.y = element_blank())+ylim(-4.1,4)
grid.arrange(p1, p2, nrow = 1, ncol = 2)
dev.off()